RetainingNode class

leaked node info

Constructors

RetainingNode(String clazz, {String? parentKey, int? parentIndex, String? string, SourceCodeLocation? sourceCodeLocation, String? parentField, String? libraries, bool important = false, ClosureInfo? closureInfo, LeakedNodeType leakedNodeType = LeakedNodeType.unknown})
RetainingNode.fromJson(Map<String, dynamic> json)

Properties

clazz ↔ String
getter/setter pair
closureInfo ↔ ClosureInfo?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
important ↔ bool
getter/setter pair
leakedNodeType ↔ LeakedNodeType
getter/setter pair
libraries ↔ String?
getter/setter pair
parentField ↔ String?
getter/setter pair
parentIndex ↔ int?
getter/setter pair
parentKey ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCodeLocation ↔ SourceCodeLocation?
getter/setter pair
string ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited